=============================
Orienter classes (docstrings)
=============================

.. module:: diofant.vector.orienters

Orienter
========

.. autoclass:: Orienter
   :members:


AxisOrienter
============

.. autoclass:: AxisOrienter
   :members:
   :special-members:


BodyOrienter
============

.. autoclass:: BodyOrienter
   :members:
   :special-members:

SpaceOrienter
=============

.. autoclass:: SpaceOrienter
   :members:
   :special-members:


QuaternionOrienter
==================

.. autoclass:: QuaternionOrienter
   :members:
   :special-members:
